@@ -31,7 +31,6 @@ def scan_table(table_name, projection, expression, last_evaluated_key, config):
     has_more = True
 
     while has_more:
-        LOGGER.info('Scanning table %s with params:', table_name)
         for key, value in scan_params.items():
             LOGGER.info('\t%s = %s', key, value)
 
@@ -81,7 +80,6 @@ def sync(config, state, stream):
                                              'last_evaluated_key')
 
     md_map = metadata.to_map(stream['metadata'])
-    LOGGER.info("Metadata here : %s",md_map)
     projection = metadata.get(md_map, (), 'tap-mongodb.projection')
 
     # An expression attribute name is a placeholder that one uses in an Amazon DynamoDB expression as an alternative to an actual attribute name.
@@ -102,7 +100,6 @@ def sync(config, state, stream):
             record_message = singer.RecordMessage(stream=table_name,
                                                   record=record,
                                                   version=stream_version)
-            LOGGER.info("Record Message : %s",record_message)
             singer.write_message(record_message)
         if result.get('LastEvaluatedKey'):
             state = singer.write_bookmark(state, table_name, 'last_evaluated_key', result.get('LastEvaluatedKey'))
@@ -116,7 +113,6 @@ def sync(config, state, stream):
                                   True)
 
     singer.write_state(state)
-    LOGGER.info("state after full table sync",state)
 
     singer.write_version(table_name, stream_version)
 
